@@ -35,7 +35,11 @@ try:
     from urlparse import urlparse, urlsplit, urljoin
 except ImportError:
     from urllib.parse import urlparse, urlsplit, urljoin  # NOQA
-import warnings
+
+try:
+    import pyphen
+except ImportError:
+    pyphen = None
 
 import lxml.html
 from yapsy.PluginManager import PluginManager
@@ -54,6 +58,7 @@ from .plugin_categories import (
     Command,
     LateTask,
     PageCompiler,
+    RestExtension,
     Task,
     TaskMultiplier,
     TemplateSystem,
@@ -80,10 +85,12 @@ class Nikola(object):
     def __init__(self, **config):
         """Setup proper environment for running tasks."""
 
+        self.strict = False
         self.global_data = {}
         self.posts_per_year = defaultdict(list)
         self.posts_per_month = defaultdict(list)
         self.posts_per_tag = defaultdict(list)
+        self.posts_per_category = defaultdict(list)
         self.post_per_file = {}
         self.timeline = []
         self.pages = []
@@ -98,47 +105,17 @@ class Nikola(object):
         # This is the default config
         self.config = {
             'ADD_THIS_BUTTONS': True,
-            'ANALYTICS': '',
             'ARCHIVE_PATH': "",
             'ARCHIVE_FILENAME': "archive.html",
+            'BLOG_TITLE': 'Default Title',
+            'BLOG_DESCRIPTION': 'Default Description',
+            'BODY_END': "",
             'CACHE_FOLDER': 'cache',
             'CODE_COLOR_SCHEME': 'default',
+            'COMMENT_SYSTEM': 'disqus',
             'COMMENTS_IN_GALLERIES': False,
             'COMMENTS_IN_STORIES': False,
-            'CONTENT_FOOTER': '',
-            'CREATE_MONTHLY_ARCHIVE': False,
-            'DATE_FORMAT': '%Y-%m-%d %H:%M',
-            'DEFAULT_LANG': "en",
-            'DEPLOY_COMMANDS': [],
-            'DISABLED_PLUGINS': (),
-            'DISQUS_FORUM': 'nikolademo',
-            'ENABLED_EXTRAS': (),
-            'EXTRA_HEAD_DATA': '',
-            'FAVICONS': {},
-            'FEED_LENGTH': 10,
-            'FILE_METADATA_REGEXP': None,
-            'FILES_FOLDERS': {'files': ''},
-            'FILTERS': {},
-            'GALLERY_PATH': 'galleries',
-            'GZIP_FILES': False,
-            'GZIP_EXTENSIONS': ('.txt', '.htm', '.html', '.css', '.js', '.json'),
-            'HIDE_SOURCELINK': False,
-            'HIDE_UNTRANSLATED_POSTS': False,
-            'INDEX_DISPLAY_POST_COUNT': 10,
-            'INDEX_FILE': 'index.html',
-            'INDEX_TEASERS': False,
-            'INDEXES_TITLE': "",
-            'INDEXES_PAGES': "",
-            'INDEX_PATH': '',
-            'LICENSE': '',
-            'LINK_CHECK_WHITELIST': [],
-            'LISTINGS_FOLDER': 'listings',
-            'MARKDOWN_EXTENSIONS': ['fenced_code', 'codehilite'],
-            'MAX_IMAGE_SIZE': 1280,
-            'MATHJAX_CONFIG': '',
-            'OLD_THEME_SUPPORT': True,
-            'OUTPUT_FOLDER': 'output',
-            'post_compilers': {
+            'COMPILERS': {
                 "rest": ('.txt', '.rst'),
                 "markdown": ('.md', '.mdown', '.markdown'),
                 "textile": ('.textile',),
@@ -148,53 +125,174 @@ class Nikola(object):
                 "ipynb": ('.ipynb',),
                 "html": ('.html', '.htm')
             },
-            'POST_PAGES': (
-                ("posts/*.txt", "posts", "post.tmpl", True),
-                ("stories/*.txt", "stories", "story.tmpl", False),
-            ),
+            'CONTENT_FOOTER': '',
+            'COPY_SOURCES': True,
+            'CREATE_MONTHLY_ARCHIVE': False,
+            'DATE_FORMAT': '%Y-%m-%d %H:%M',
+            'DEFAULT_LANG': "en",
+            'DEPLOY_COMMANDS': [],
+            'DISABLED_PLUGINS': (),
+            'COMMENT_SYSTEM_ID': 'nikolademo',
+            'ENABLED_EXTRAS': (),
+            'EXTRA_HEAD_DATA': '',
+            'FAVICONS': {},
+            'FEED_LENGTH': 10,
+            'FILE_METADATA_REGEXP': None,
+            'ADDITIONAL_METADATA': {},
+            'FILES_FOLDERS': {'files': ''},
+            'FILTERS': {},
+            'GALLERY_PATH': 'galleries',
+            'GZIP_COMMAND': None,
+            'GZIP_FILES': False,
+            'GZIP_EXTENSIONS': ('.txt', '.htm', '.html', '.css', '.js', '.json'),
+            'HIDE_SOURCELINK': False,
+            'HIDE_UNTRANSLATED_POSTS': False,
+            'HYPHENATE': False,
+            'INDEX_DISPLAY_POST_COUNT': 10,
+            'INDEX_FILE': 'index.html',
+            'INDEX_TEASERS': False,
+            'INDEXES_TITLE': "",
+            'INDEXES_PAGES': "",
+            'INDEX_PATH': '',
+            'LICENSE': '',
+            'LINK_CHECK_WHITELIST': [],
+            'LISTINGS_FOLDER': 'listings',
+            'NAVIGATION_LINKS': None,
+            'MARKDOWN_EXTENSIONS': ['fenced_code', 'codehilite'],
+            'MAX_IMAGE_SIZE': 1280,
+            'MATHJAX_CONFIG': '',
+            'OLD_THEME_SUPPORT': True,
+            'OUTPUT_FOLDER': 'output',
+            'POSTS': (("posts/*.txt", "posts", "post.tmpl"),),
+            'PAGES': (("stories/*.txt", "stories", "story.tmpl"),),
             'PRETTY_URLS': False,
+            'FUTURE_IS_NOW': False,
+            'READ_MORE_LINK': '<p class="more"><a href="{link}">{read_more}…</a></p>',
             'REDIRECTIONS': [],
             'RSS_LINK': None,
             'RSS_PATH': '',
             'RSS_TEASERS': True,
             'SEARCH_FORM': '',
             'SLUG_TAG_PATH': True,
+            'SOCIAL_BUTTONS_CODE': SOCIAL_BUTTONS_CODE,
+            'SITE_URL': 'http://getnikola.com/',
             'STORY_INDEX': False,
             'STRIP_INDEXES': False,
             'SITEMAP_INCLUDE_FILELESS_DIRS': True,
             'TAG_PATH': 'categories',
             'TAG_PAGES_ARE_INDEXES': False,
-            'THEME': 'site',
-            'THEME_REVEAL_CONGIF_SUBTHEME': 'sky',
-            'THEME_REVEAL_CONGIF_TRANSITION': 'cube',
+            'THEME': 'bootstrap',
+            'THEME_REVEAL_CONFIG_SUBTHEME': 'sky',
+            'THEME_REVEAL_CONFIG_TRANSITION': 'cube',
             'THUMBNAIL_SIZE': 180,
             'USE_BUNDLES': True,
             'USE_CDN': False,
             'USE_FILENAME_AS_TITLE': True,
             'TIMEZONE': None,
+            'DEPLOY_DRAFTS': True,
+            'DEPLOY_FUTURE': False,
+            'SCHEDULE_ALL': False,
+            'SCHEDULE_RULE': '',
+            'SCHEDULE_FORCE_TODAY': False
         }
 
         self.config.update(config)
 
+        # Make sure we have pyphen installed if we are using it
+        if self.config.get('HYPHENATE') and pyphen is None:
+            utils.LOGGER.warn('To use the hyphenation, you have to install '
+                              'the "pyphen" package.')
+            utils.LOGGER.warn('Setting HYPHENATE to False.')
+            self.config['HYPHENATE'] = False
+
+        # Deprecating post_compilers
+        # TODO: remove on v7
+        if 'post_compilers' in config:
+            utils.LOGGER.warn('The post_compilers option is deprecated, use COMPILERS instead.')
+            if 'COMPILERS' in config:
+                utils.LOGGER.warn('COMPILERS conflicts with post_compilers, ignoring post_compilers.')
+            else:
+                self.config['COMPILERS'] = config['post_compilers']
+
+        # Deprecating post_pages
+        # TODO: remove on v7
+        if 'post_pages' in config:
+            utils.LOGGER.warn('The post_pages option is deprecated, use POSTS and PAGES instead.')
+            if 'POSTS' in config or 'PAGES' in config:
+                utils.LOGGER.warn('POSTS and PAGES conflict with post_pages, ignoring post_pages.')
+            else:
+                self.config['POSTS'] = [item[:3] for item in config['post_pages'] if item[-1]]
+                self.config['PAGES'] = [item[:3] for item in config['post_pages'] if not item[-1]]
+        # FIXME: Internally, we still use post_pages because it's a pain to change it
+        self.config['post_pages'] = []
+        for i1, i2, i3 in self.config['POSTS']:
+            self.config['post_pages'].append([i1, i2, i3, True])
+        for i1, i2, i3 in self.config['PAGES']:
+            self.config['post_pages'].append([i1, i2, i3, False])
+
+        # Deprecating DISQUS_FORUM
+        # TODO: remove on v7
+        if 'DISQUS_FORUM' in config:
+            utils.LOGGER.warn('The DISQUS_FORUM option is deprecated, use COMMENT_SYSTEM_ID instead.')
+            if 'COMMENT_SYSTEM_ID' in config:
+                utils.LOGGER.warn('DISQUS_FORUM conflicts with COMMENT_SYSTEM_ID, ignoring DISQUS_FORUM.')
+            else:
+                self.config['COMMENT_SYSTEM_ID'] = config['DISQUS_FORUM']
+
+        # Deprecating the ANALYTICS option
+        # TODO: remove on v7
+        if 'ANALYTICS' in config:
+            utils.LOGGER.warn('The ANALYTICS option is deprecated, use BODY_END instead.')
+            if 'BODY_END' in config:
+                utils.LOGGER.warn('ANALYTICS conflicts with BODY_END, ignoring ANALYTICS.')
+            else:
+                self.config['BODY_END'] = config['ANALYTICS']
+
+        # Deprecating the SIDEBAR_LINKS option
+        # TODO: remove on v7
+        if 'SIDEBAR_LINKS' in config:
+            utils.LOGGER.warn('The SIDEBAR_LINKS option is deprecated, use NAVIGATION_LINKS instead.')
+            if 'NAVIGATION_LINKS' in config:
+                utils.LOGGER.warn('The SIDEBAR_LINKS conflicts with NAVIGATION_LINKS, ignoring SIDEBAR_LINKS.')
+            else:
+                self.config['NAVIGATION_LINKS'] = config['SIDEBAR_LINKS']
+        # Compatibility alias
+        self.config['SIDEBAR_LINKS'] = self.config['NAVIGATION_LINKS']
+
+        if self.config['NAVIGATION_LINKS'] in (None, {}):
+            self.config['NAVIGATION_LINKS'] = {self.config['DEFAULT_LANG']: ()}
+
+        # Deprecating the ADD_THIS_BUTTONS option
+        # TODO: remove on v7
+        if 'ADD_THIS_BUTTONS' in config:
+            utils.LOGGER.warn('The ADD_THIS_BUTTONS option is deprecated, use SOCIAL_BUTTONS_CODE instead.')
+            if not config['ADD_THIS_BUTTONS']:
+                utils.LOGGER.warn('Setting SOCIAL_BUTTONS_CODE to empty because ADD_THIS_BUTTONS is False.')
+                self.config['SOCIAL_BUTTONS_CODE'] = ''
+
         # STRIP_INDEX_HTML config has been replaces with STRIP_INDEXES
         # Port it if only the oldef form is there
+        # TODO: remove on v7
         if 'STRIP_INDEX_HTML' in config and 'STRIP_INDEXES' not in config:
-            print("WARNING: You should configure STRIP_INDEXES instead of STRIP_INDEX_HTML")
+            utils.LOGGER.warn('You should configure STRIP_INDEXES instead of STRIP_INDEX_HTML')
             self.config['STRIP_INDEXES'] = config['STRIP_INDEX_HTML']
 
         # PRETTY_URLS defaults to enabling STRIP_INDEXES unless explicitly disabled
         if config.get('PRETTY_URLS', False) and 'STRIP_INDEXES' not in config:
             self.config['STRIP_INDEXES'] = True
 
+        if config.get('COPY_SOURCES') and not self.config['HIDE_SOURCELINK']:
+            self.config['HIDE_SOURCELINK'] = True
+
         self.config['TRANSLATIONS'] = self.config.get('TRANSLATIONS',
-                                                      {self.config['DEFAULT_'
-                                                      'LANG']: ''})
+                                                      {self.config['DEFAULT_LANG']: ''})
 
         # SITE_URL is required, but if the deprecated BLOG_URL
         # is available, use it and warn
+        # TODO: remove on v7
         if 'SITE_URL' not in self.config:
             if 'BLOG_URL' in self.config:
-                print("WARNING: You should configure SITE_URL instead of BLOG_URL")
+                utils.LOGGER.warn('You should configure SITE_URL instead of BLOG_URL')
                 self.config['SITE_URL'] = self.config['BLOG_URL']
 
         self.default_lang = self.config['DEFAULT_LANG']
@@ -203,6 +301,9 @@ class Nikola(object):
         # BASE_URL defaults to SITE_URL
         if 'BASE_URL' not in self.config:
             self.config['BASE_URL'] = self.config.get('SITE_URL')
+        # BASE_URL should *always* end in /
+        if self.config['BASE_URL'] and self.config['BASE_URL'][-1] != '/':
+            utils.LOGGER.warn("Your BASE_URL doesn't end in / -- adding it.")
 
         self.plugin_manager = PluginManager(categories_filter={
             "Command": Command,
@@ -211,6 +312,7 @@ class Nikola(object):
             "TemplateSystem": TemplateSystem,
             "PageCompiler": PageCompiler,
             "TaskMultiplier": TaskMultiplier,
+            "RestExtension": RestExtension,
         })
         self.plugin_manager.setPluginInfoExtension('plugin')
         if sys.version_info[0] == 3:
@@ -263,7 +365,7 @@ class Nikola(object):
 
         # Activate all required compiler plugins
         for plugin_info in self.plugin_manager.getPluginsOfCategory("PageCompiler"):
-            if plugin_info.name in self.config["post_compilers"].keys():
+            if plugin_info.name in self.config["COMPILERS"].keys():
                 self.plugin_manager.activatePluginByName(plugin_info.name)
                 plugin_info.plugin_object.set_site(self)
 
@@ -278,8 +380,6 @@ class Nikola(object):
         self._GLOBAL_CONTEXT['SLUG_TAG_PATH'] = self.config[
             'SLUG_TAG_PATH']
 
-        self._GLOBAL_CONTEXT['add_this_buttons'] = self.config[
-            'ADD_THIS_BUTTONS']
         self._GLOBAL_CONTEXT['index_display_post_count'] = self.config[
             'INDEX_DISPLAY_POST_COUNT']
         self._GLOBAL_CONTEXT['use_bundles'] = self.config['USE_BUNDLES']
@@ -290,25 +390,37 @@ class Nikola(object):
         self._GLOBAL_CONTEXT['blog_author'] = self.config.get('BLOG_AUTHOR')
         self._GLOBAL_CONTEXT['blog_title'] = self.config.get('BLOG_TITLE')
 
+        # TODO: remove fallback in v7
         self._GLOBAL_CONTEXT['blog_url'] = self.config.get('SITE_URL', self.config.get('BLOG_URL'))
         self._GLOBAL_CONTEXT['blog_desc'] = self.config.get('BLOG_DESCRIPTION')
-        self._GLOBAL_CONTEXT['analytics'] = self.config.get('ANALYTICS')
+        self._GLOBAL_CONTEXT['body_end'] = self.config.get('BODY_END')
+        # TODO: remove in v7
+        self._GLOBAL_CONTEXT['analytics'] = self.config.get('BODY_END')
+        # TODO: remove in v7
+        self._GLOBAL_CONTEXT['add_this_buttons'] = self.config.get('SOCIAL_BUTTONS_CODE')
+        self._GLOBAL_CONTEXT['social_buttons_code'] = self.config.get('SOCIAL_BUTTONS_CODE')
         self._GLOBAL_CONTEXT['translations'] = self.config.get('TRANSLATIONS')
         self._GLOBAL_CONTEXT['license'] = self.config.get('LICENSE')
         self._GLOBAL_CONTEXT['search_form'] = self.config.get('SEARCH_FORM')
-        self._GLOBAL_CONTEXT['disqus_forum'] = self.config.get('DISQUS_FORUM')
+        self._GLOBAL_CONTEXT['comment_system'] = self.config.get('COMMENT_SYSTEM')
+        self._GLOBAL_CONTEXT['comment_system_id'] = self.config.get('COMMENT_SYSTEM_ID')
+        # TODO: remove in v7
+        self._GLOBAL_CONTEXT['disqus_forum'] = self.config.get('COMMENT_SYSTEM_ID')
         self._GLOBAL_CONTEXT['mathjax_config'] = self.config.get(
             'MATHJAX_CONFIG')
-        self._GLOBAL_CONTEXT['subtheme'] = self.config.get('THEME_REVEAL_CONGIF_SUBTHEME')
-        self._GLOBAL_CONTEXT['transition'] = self.config.get('THEME_REVEAL_CONGIF_TRANSITION')
+        self._GLOBAL_CONTEXT['subtheme'] = self.config.get('THEME_REVEAL_CONFIG_SUBTHEME')
+        self._GLOBAL_CONTEXT['transition'] = self.config.get('THEME_REVEAL_CONFIG_TRANSITION')
         self._GLOBAL_CONTEXT['content_footer'] = self.config.get(
             'CONTENT_FOOTER')
         self._GLOBAL_CONTEXT['rss_path'] = self.config.get('RSS_PATH')
         self._GLOBAL_CONTEXT['rss_link'] = self.config.get('RSS_LINK')
 
-        self._GLOBAL_CONTEXT['sidebar_links'] = utils.Functionary(list, self.config['DEFAULT_LANG'])
-        for k, v in self.config.get('SIDEBAR_LINKS', {}).items():
-            self._GLOBAL_CONTEXT['sidebar_links'][k] = v
+        self._GLOBAL_CONTEXT['navigation_links'] = utils.Functionary(list, self.config['DEFAULT_LANG'])
+        for k, v in self.config.get('NAVIGATION_LINKS', {}).items():
+            self._GLOBAL_CONTEXT['navigation_links'][k] = v
+        # TODO: remove on v7
+        # Compatibility alias
+        self._GLOBAL_CONTEXT['sidebar_links'] = self._GLOBAL_CONTEXT['navigation_links']
 
         self._GLOBAL_CONTEXT['twitter_card'] = self.config.get(
             'TWITTER_CARD', {})
@@ -329,13 +441,33 @@ class Nikola(object):
 
     def _get_themes(self):
         if self._THEMES is None:
-            self._THEMES = utils.get_theme_chain(self.config['THEME'])
+            # Check for old theme names (Issue #650) TODO: remove in v7
+            theme_replacements = {
+                'site': 'bootstrap',
+                'orphan': 'base',
+                'default': 'oldfashioned',
+            }
+            if self.config['THEME'] in theme_replacements:
+                utils.LOGGER.warn('You are using the old theme "{0}", using "{1}" instead.'.format(
+                    self.config['THEME'], theme_replacements[self.config['THEME']]))
+                self.config['THEME'] = theme_replacements[self.config['THEME']]
+                if self.config['THEME'] == 'oldfashioned':
+                    utils.LOGGER.warn('''You may need to install the "oldfashioned" theme '''
+                                      '''from themes.nikola.ralsina.com.ar because it's not '''
+                                      '''shipped by default anymore.''')
+                utils.LOGGER.warn('Please change your THEME setting.')
+            try:
+                self._THEMES = utils.get_theme_chain(self.config['THEME'])
+            except Exception:
+                utils.LOGGER.warn('''Can't load theme "{0}", using 'bootstrap' instead.'''.format(self.config['THEME']))
+                self.config['THEME'] = 'bootstrap'
+                return self._get_themes()
             # Check consistency of USE_CDN and the current THEME (Issue #386)
             if self.config['USE_CDN']:
                 bootstrap_path = utils.get_asset_path(os.path.join(
                     'assets', 'css', 'bootstrap.min.css'), self._THEMES)
-                if bootstrap_path.split(os.sep)[-4] != 'site':
-                    warnings.warn('The USE_CDN option may be incompatible with your theme, because it uses a hosted version of bootstrap.')
+                if bootstrap_path and bootstrap_path.split(os.sep)[-4] not in ['bootstrap', 'bootstrap3']:
+                    utils.LOGGER.warn('The USE_CDN option may be incompatible with your theme, because it uses a hosted version of bootstrap.')
 
         return self._THEMES
 
@@ -388,7 +520,7 @@ class Nikola(object):
     template_system = property(_get_template_system)
 
     def get_compiler(self, source_name):
-        """Get the correct compiler for a post from `conf.post_compilers`
+        """Get the correct compiler for a post from `conf.COMPILERS`
         To make things easier for users, the mapping in conf.py is
         compiler->[extensions], although this is less convenient for us. The
         majority of this function is reversing that dictionary and error
@@ -400,18 +532,18 @@ class Nikola(object):
         except KeyError:
             # Find the correct compiler for this files extension
             langs = [lang for lang, exts in
-                     list(self.config['post_compilers'].items())
+                     list(self.config['COMPILERS'].items())
                      if ext in exts]
             if len(langs) != 1:
                 if len(set(langs)) > 1:
                     exit("Your file extension->compiler definition is"
                          "ambiguous.\nPlease remove one of the file extensions"
-                         "from 'post_compilers' in conf.py\n(The error is in"
+                         "from 'COMPILERS' in conf.py\n(The error is in"
                          "one of {0})".format(', '.join(langs)))
                 elif len(langs) > 1:
                     langs = langs[:1]
                 else:
-                    exit("post_compilers in conf.py does not tell me how to "
+                    exit("COMPILERS in conf.py does not tell me how to "
                          "handle '{0}' extensions.".format(ext))
 
             lang = langs[0]
@@ -484,10 +616,7 @@ class Nikola(object):
 
             return result
 
-        try:
-            os.makedirs(os.path.dirname(output_name))
-        except:
-            pass
+        utils.makedirs(os.path.dirname(output_name))
         doc = lxml.html.document_fromstring(data)
         doc.rewrite_links(replacer)
         data = b'<!DOCTYPE html>' + lxml.html.tostring(doc, encoding='utf8')
@@ -515,12 +644,14 @@ class Nikola(object):
         * tag_index (name is ignored)
         * tag (and name is the tag name)
         * tag_rss (name is the tag name)
+        * category (and name is the category name)
+        * category_rss (and name is the category name)
         * archive (and name is the year, or None for the main archive index)
         * index (name is the number in index-number)
         * rss (name is ignored)
         * gallery (name is the gallery name)
         * listing (name is the source code file name)
-        * post_path (name is 1st element in a post_pages tuple)
+        * post_path (name is 1st element in a POSTS/PAGES tuple)
 
         The returned value is always a path relative to output, like
         "categories/whatever.html"
@@ -547,12 +678,25 @@ class Nikola(object):
             path = [_f for _f in [self.config['TRANSLATIONS'][lang],
                                   self.config['TAG_PATH'], name + ".html"] if
                     _f]
+
+        elif kind == "category":
+            if self.config['SLUG_TAG_PATH']:
+                name = utils.slugify(name)
+            path = [_f for _f in [self.config['TRANSLATIONS'][lang],
+                                  self.config['TAG_PATH'], "cat_" + name + ".html"] if
+                    _f]
         elif kind == "tag_rss":
             if self.config['SLUG_TAG_PATH']:
                 name = utils.slugify(name)
             path = [_f for _f in [self.config['TRANSLATIONS'][lang],
                                   self.config['TAG_PATH'], name + ".xml"] if
                     _f]
+        elif kind == "category_rss":
+            if self.config['SLUG_TAG_PATH']:
+                name = utils.slugify(name)
+            path = [_f for _f in [self.config['TRANSLATIONS'][lang],
+                                  self.config['TAG_PATH'], "cat_" + name + ".xml"] if
+                    _f]
         elif kind == "index":
             if name not in [None, 0]:
                 path = [_f for _f in [self.config['TRANSLATIONS'][lang],
@@ -637,6 +781,13 @@ class Nikola(object):
             exists = os.stat(path).st_size > 0
         return exists
 
+    def clean_task_paths(self, task):
+        """Normalize target paths in the task."""
+        targets = task.get('targets', None)
+        if targets is not None:
+            task['targets'] = [os.path.normpath(t) for t in targets]
+        return task
+
     def gen_tasks(self, name, plugin_category):
 
         def flatten(task):
@@ -650,12 +801,13 @@ class Nikola(object):
         task_dep = []
         for pluginInfo in self.plugin_manager.getPluginsOfCategory(plugin_category):
             for task in flatten(pluginInfo.plugin_object.gen_tasks()):
+                task = self.clean_task_paths(task)
                 yield task
                 for multi in self.plugin_manager.getPluginsOfCategory("TaskMultiplier"):
                     flag = False
                     for task in multi.plugin_object.process(task, name):
                         flag = True
-                        yield task
+                        yield self.clean_task_paths(task)
                     if flag:
                         task_dep.append('{0}_{1}'.format(name, multi.plugin_object.name))
             if pluginInfo.plugin_object.is_default:
@@ -671,12 +823,15 @@ class Nikola(object):
         """Scan all the posts."""
         if self._scanned:
             return
-
+        seen = set([])
         print("Scanning posts", end='')
         tzinfo = None
         if self.config['TIMEZONE'] is not None:
             tzinfo = pytz.timezone(self.config['TIMEZONE'])
-        current_time = utils.current_time(tzinfo)
+        if self.config['FUTURE_IS_NOW']:
+            current_time = None
+        else:
+            current_time = utils.current_time(tzinfo)
         targets = set([])
         for wildcard, destination, template_name, use_in_feeds in \
                 self.config['post_pages']:
@@ -699,9 +854,13 @@ class Nikola(object):
                 # We eliminate from the list the files inside any .ipynb folder
                 full_list = [p for p in full_list
                              if not any([x.startswith('.')
-                             for x in p.split(os.sep)])]
+                                         for x in p.split(os.sep)])]
 
                 for base_path in full_list:
+                    if base_path in seen:
+                        continue
+                    else:
+                        seen.add(base_path)
                     post = Post(
                         base_path,
                         self.config['CACHE_FOLDER'],
@@ -719,6 +878,7 @@ class Nikola(object):
                         current_time,
                         self.config['HIDE_UNTRANSLATED_POSTS'],
                         self.config['PRETTY_URLS'],
+                        self.config['HYPHENATE'],
                     )
                     for lang, langpath in list(
                             self.config['TRANSLATIONS'].items()):
@@ -738,6 +898,7 @@ class Nikola(object):
                             '{0}/{1:02d}'.format(post.date.year, post.date.month)].append(post.post_name)
                         for tag in post.alltags:
                             self.posts_per_tag[tag].append(post.post_name)
+                        self.posts_per_category[post.meta('category')].append(post.post_name)
                     else:
                         self.pages.append(post)
                     if self.config['OLD_THEME_SUPPORT']:
@@ -762,6 +923,8 @@ class Nikola(object):
         context = {}
         deps = post.deps(lang) + \
             self.template_system.template_deps(post.template_name)
+        deps.extend(utils.get_asset_path(x, self.THEMES) for x in ('bundles', 'parent', 'engine'))
+        deps = list(filter(None, deps))
         context['post'] = post
         context['lang'] = lang
         context['title'] = post.title(lang)
@@ -838,6 +1001,22 @@ def s_l(lang):
     try:
         locale.setlocale(locale.LC_ALL, (lang, "utf8"))
     except Exception:
-        print("WARNING: could not set locale to {0}."
-              "This may cause some i18n features not to work.".format(lang))
+        utils.LOGGER.warn(
+            "Could not set locale to {0}."
+            "This may cause some i18n features not to work.".format(lang))
     return ''
+
+
+SOCIAL_BUTTONS_CODE = """
+<!-- Social buttons -->
+<div id="addthisbox" class="addthis_toolbox addthis_peekaboo_style addthis_default_style addthis_label_style addthis_32x32_style">
+<a class="addthis_button_more">Share</a>
+<ul><li><a class="addthis_button_facebook"></a>
+<li><a class="addthis_button_google_plusone_share"></a>
+<li><a class="addthis_button_linkedin"></a>
+<li><a class="addthis_button_twitter"></a>
+</ul>
+</div>
+<script type="text/javascript" src="//s7.addthis.com/js/300/addthis_widget.js#pubid=ra-4f7088a56bb93798"></script>
+<!-- End of social buttons -->
+"""
