@@ -24,17 +24,23 @@
 # OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
+from __future__ import absolute_import
+
 __all__ = [
     'Command',
     'LateTask',
     'PageCompiler',
+    'RestExtension',
     'Task',
+    'TaskMultiplier',
     'TemplateSystem'
 ]
 
 from yapsy.IPlugin import IPlugin
 from doit.cmd_base import Command as DoitCommand
 
+from .utils import LOGGER
+
 
 class BasePlugin(IPlugin):
     """Base plugin class."""
@@ -65,7 +71,7 @@ class Command(BasePlugin, DoitCommand):
         """Check if the command can run in the current environment,
         fail if needed, or call _execute."""
         if self.needs_config and not self.site.configured:
-            print("This command needs to run inside an existing Nikola site.")
+            LOGGER.error("This command needs to run inside an existing Nikola site.")
             return False
         self._execute(options, args)
 
@@ -180,6 +186,10 @@ class PageCompiler(BasePlugin):
         return ".html"
 
 
+class RestExtension(BasePlugin):
+    name = "dummy_rest_extension"
+
+
 class Importer(Command):
     """Basic structure for importing data into Nikola.
 
