@@ -44,9 +44,18 @@ try:
 except ImportError:
     pass
 
+import logbook
+from logbook.more import ExceptionHandler
 import pytz
 
 
+class ApplicationWarning(Exception):
+    pass
+
+
+LOGGER = logbook.Logger('Nikola')
+STRICT_HANDLER = ExceptionHandler(ApplicationWarning, level='WARNING')
+
 if sys.version_info[0] == 3:
     # Python 3
     bytes_str = bytes
@@ -68,7 +77,8 @@ __all__ = ['get_theme_path', 'get_theme_chain', 'load_messages', 'copy_tree',
            'generic_rss_renderer', 'copy_file', 'slugify', 'unslugify',
            'to_datetime', 'apply_filters', 'config_changed', 'get_crumbs',
            'get_tzname', 'get_asset_path', '_reload', 'unicode_str', 'bytes_str',
-           'unichr', 'Functionary', 'LocaleBorg', 'sys_encode', 'sys_decode']
+           'unichr', 'Functionary', 'LocaleBorg', 'sys_encode', 'sys_decode',
+           'makedirs']
 
 
 ENCODING = sys.getfilesystemencoding() or sys.stdin.encoding
@@ -88,6 +98,15 @@ def sys_decode(thing):
     return thing
 
 
+def makedirs(path):
+    """Create a folder."""
+    if os.path.isdir(path):
+        return
+    if os.path.exists(path):
+        raise OSError('Path {0} already exists and is not a folder.')
+    os.makedirs(path)
+
+
 class Functionary(defaultdict):
 
     """Class that looks like a function, but is a defaultdict."""
@@ -194,6 +213,9 @@ def get_theme_chain(theme):
     return themes
 
 
+warned = []
+
+
 def load_messages(themes, translations, default_lang):
     """ Load theme's messages into context.
 
@@ -201,11 +223,10 @@ def load_messages(themes, translations, default_lang):
     and "younger" themes have priority.
     """
     messages = Functionary(dict, default_lang)
-    warned = []
     oldpath = sys.path[:]
     for theme_name in themes[::-1]:
         msg_folder = os.path.join(get_theme_path(theme_name), 'messages')
-        default_folder = os.path.join(get_theme_path('default'), 'messages')
+        default_folder = os.path.join(get_theme_path('base'), 'messages')
         sys.path.insert(0, default_folder)
         sys.path.insert(0, msg_folder)
         english = __import__('messages_en')
@@ -214,12 +235,11 @@ def load_messages(themes, translations, default_lang):
             translation = __import__('messages_' + lang)
             reload(translation)
             if sorted(translation.MESSAGES.keys()) !=\
-                sorted(english.MESSAGES.keys()) and \
+                    sorted(english.MESSAGES.keys()) and \
                     lang not in warned:
-                # FIXME: get real logging in place
-                print("Warning: Incomplete translation for language "
-                      "'{0}'.".format(lang))
                 warned.append(lang)
+                LOGGER.warn("Incomplete translation for language "
+                      "'{0}'.".format(lang))
             messages[lang].update(english.MESSAGES)
             messages[lang].update(translation.MESSAGES)
             del(translation)
@@ -249,8 +269,7 @@ def copy_tree(src, dst, link_cutoff=None):
         if set(root_parts) & ignore:
             continue
         dst_dir = os.path.join(dst, *root_parts[base_len:])
-        if not os.path.isdir(dst_dir):
-            os.makedirs(dst_dir)
+        makedirs(dst_dir)
         for src_name in files:
             if src_name == '.DS_Store':
                 continue
@@ -266,14 +285,14 @@ def copy_tree(src, dst, link_cutoff=None):
 
 
 def generic_rss_renderer(lang, title, link, description, timeline, output_path,
-                         rss_teasers, feed_length=10):
+                         rss_teasers, feed_length=10, feed_url=None):
     """Takes all necessary data, and renders a RSS feed in output_path."""
     items = []
     for post in timeline[:feed_length]:
         args = {
             'title': post.title(lang),
             'link': post.permalink(lang, absolute=True),
-            'description': post.text(lang, teaser_only=rss_teasers),
+            'description': post.text(lang, teaser_only=rss_teasers, really_absolute=True),
             'guid': post.permalink(lang, absolute=True),
             # PyRSS2Gen's pubDate is GMT time.
             'pubDate': (post.date if post.date.tzinfo is None else
@@ -281,7 +300,7 @@ def generic_rss_renderer(lang, title, link, description, timeline, output_path,
             'categories': post._tags.get(lang, []),
         }
         items.append(rss.RSSItem(**args))
-    rss_obj = rss.RSS2(
+    rss_obj = ExtendedRSS2(
         title=title,
         link=link,
         description=description,
@@ -289,9 +308,10 @@ def generic_rss_renderer(lang, title, link, description, timeline, output_path,
         items=items,
         generator='nikola',
     )
+    rss_obj.self_url = feed_url
+    rss_obj.rss_attrs["xmlns:atom"] = "http://www.w3.org/2005/Atom"
     dst_dir = os.path.dirname(output_path)
-    if not os.path.isdir(dst_dir):
-        os.makedirs(dst_dir)
+    makedirs(dst_dir)
     with codecs.open(output_path, "wb+", "utf-8") as rss_file:
         data = rss_obj.to_xml(encoding='utf-8')
         if isinstance(data, bytes_str):
@@ -301,8 +321,7 @@ def generic_rss_renderer(lang, title, link, description, timeline, output_path,
 
 def copy_file(source, dest, cutoff=None):
     dst_dir = os.path.dirname(dest)
-    if not os.path.isdir(dst_dir):
-        os.makedirs(dst_dir)
+    makedirs(dst_dir)
     if os.path.islink(source):
         link_target = os.path.relpath(
             os.path.normpath(os.path.join(dst_dir, os.readlink(source))))
@@ -363,7 +382,7 @@ def unslugify(value):
     """
     Given a slug string (as a filename), return a human readable string
     """
-    value = re.sub('^[0-9]', '', value)
+    value = re.sub('^[0-9]+', '', value)
     value = re.sub('([_\-\.])', ' ', value)
     value = value.strip().capitalize()
     return value
@@ -387,12 +406,7 @@ def extract_all(zipfile):
                                          'not safe to expand.')
         for f in namelist:
             if f.endswith('/'):
-                if not os.path.isdir(f):
-                    try:
-                        os.makedirs(f)
-                    except:
-                        raise OSError("Failed making {0} directory "
-                                      "tree!".format(f))
+                makedirs(f)
             else:
                 z.extract(f)
     os.chdir(pwd)
@@ -481,7 +495,7 @@ def apply_filters(task, filters):
             else:
                 assert False, key
 
-    for target in task['targets']:
+    for target in task.get('targets', []):
         ext = os.path.splitext(target)[-1].lower()
         filter_ = filter_matches(ext)
         if filter_:
@@ -548,16 +562,16 @@ def get_asset_path(path, themes, files_folders={'files': ''}):
     If the asset is not provided by a theme, then it will be checked for
     in the FILES_FOLDERS
 
-    >>> print(get_asset_path('assets/css/rst.css', ['site', 'default']))
-    nikola/data/themes/default/assets/css/rst.css
+    >>> print(get_asset_path('assets/css/rst.css', ['bootstrap', 'base']))
+    nikola/data/themes/base/assets/css/rst.css
 
-    >>> print(get_asset_path('assets/css/theme.css', ['site', 'default']))
-    nikola/data/themes/site/assets/css/theme.css
+    >>> print(get_asset_path('assets/css/theme.css', ['bootstrap', 'base']))
+    nikola/data/themes/bootstrap/assets/css/theme.css
 
-    >>> print(get_asset_path('nikola.py', ['site', 'default'], {'nikola': ''}))
+    >>> print(get_asset_path('nikola.py', ['bootstrap', 'base'], {'nikola': ''}))
     nikola/nikola.py
 
-    >>> print(get_asset_path('nikola/nikola.py', ['site', 'default'],
+    >>> print(get_asset_path('nikola/nikola.py', ['bootstrap', 'base'],
     ... {'nikola':'nikola'}))
     nikola/nikola.py
 
@@ -588,3 +602,14 @@ class LocaleBorg:
 
     def __init__(self):
         self.__dict__ = self.__shared_state
+
+
+class ExtendedRSS2(rss.RSS2):
+    def publish_extensions(self, handler):
+        if self.self_url:
+            handler.startElement("atom:link", {
+                'href': self.self_url,
+                'rel': "self",
+                'type': "application/rss+xml"
+            })
+            handler.endElement("atom:link")
