@@ -6,10 +6,13 @@ import os
 import unittest
 import mock
 
+import nikola.plugins.command.import_wordpress
+
 
 class BasicCommandImportWordpress(unittest.TestCase):
     def setUp(self):
-        self.import_command = nikola.plugins.command_import_wordpress.CommandImportWordpress()
+        self.module = nikola.plugins.command.import_wordpress
+        self.import_command = self.module.CommandImportWordpress()
         self.import_filename = os.path.abspath(os.path.join(
             os.path.dirname(__file__), 'wordpress_export_example.xml'))
 
@@ -51,11 +54,11 @@ class CommandImportWordpressRunTest(BasicCommandImportWordpress):
 
         site_generation_patch = mock.patch('os.system', self.site_generation)
         data_import_patch = mock.patch(
-            'nikola.plugins.command_import_wordpress.CommandImportWordpress.import_posts', self.data_import)
+            'nikola.plugins.command.import_wordpress.CommandImportWordpress.import_posts', self.data_import)
         write_urlmap_patch = mock.patch(
-            'nikola.plugins.command_import_wordpress.CommandImportWordpress.write_urlmap_csv', self.write_urlmap)
+            'nikola.plugins.command.import_wordpress.CommandImportWordpress.write_urlmap_csv', self.write_urlmap)
         write_configuration_patch = mock.patch(
-            'nikola.plugins.command_import_wordpress.CommandImportWordpress.write_configuration', self.write_configuration)
+            'nikola.plugins.command.import_wordpress.CommandImportWordpress.write_configuration', self.write_configuration)
 
         self.patches = [site_generation_patch, data_import_patch,
                         write_urlmap_patch, write_configuration_patch]
@@ -117,7 +120,7 @@ class CommandImportWordpressTest(BasicCommandImportWordpress):
             self.import_filename)
         context = self.import_command.populate_context(channel)
 
-        for required_key in ('POST_PAGES', 'POST_COMPILERS'):
+        for required_key in ('POSTS', 'PAGES', 'COMPILERS'):
             self.assertTrue(required_key in context)
 
         self.assertEqual('de', context['DEFAULT_LANG'])
@@ -133,19 +136,22 @@ class CommandImportWordpressTest(BasicCommandImportWordpress):
             self.import_filename)
         self.import_command.context = self.import_command.populate_context(
             channel)
-        self.import_command.url_map = {}  # For testing we use an empty one.
         self.import_command.output_folder = 'new_site'
         self.import_command.squash_newlines = True
         self.import_command.no_downloads = False
 
+        # Ensuring clean results
+        self.import_command.url_map = {}
+        self.module.links = {}
+
         write_metadata = mock.MagicMock()
         write_content = mock.MagicMock()
         download_mock = mock.MagicMock()
 
-        with mock.patch('nikola.plugins.command_import_wordpress.CommandImportWordpress.write_content', write_content):
-            with mock.patch('nikola.plugins.command_import_wordpress.CommandImportWordpress.write_metadata', write_metadata):
-                with mock.patch('nikola.plugins.command_import_wordpress.CommandImportWordpress.download_url_content_to_file', download_mock):
-                    with mock.patch('nikola.plugins.command_import_wordpress.os.makedirs'):
+        with mock.patch('nikola.plugins.command.import_wordpress.CommandImportWordpress.write_content', write_content):
+            with mock.patch('nikola.plugins.command.import_wordpress.CommandImportWordpress.write_metadata', write_metadata):
+                with mock.patch('nikola.plugins.command.import_wordpress.CommandImportWordpress.download_url_content_to_file', download_mock):
+                    with mock.patch('nikola.plugins.command.import_wordpress.os.makedirs'):
                         self.import_command.import_posts(channel)
 
         self.assertTrue(download_mock.called)
@@ -209,15 +215,36 @@ Diese Daten sind f\xfcr mich nicht bestimmten Personen zuordenbar. Eine Zusammen
             self.import_command.url_map['http://some.blog/kontakt/'],
             'http://some.blog/stories/kontakt.html')
 
+        image_thumbnails = [
+            'http://some.blog/wp-content/uploads/2012/12/2012-12-19-1355925145_1024x600_scrot-64x64.png',
+            'http://some.blog/wp-content/uploads/2012/12/2012-12-19-1355925145_1024x600_scrot-300x175.png',
+            'http://some.blog/wp-content/uploads/2012/12/2012-12-19-1355925145_1024x600_scrot-36x36.png',
+            'http://some.blog/wp-content/uploads/2012/12/2012-12-19-1355925145_1024x600_scrot-24x24.png',
+            'http://some.blog/wp-content/uploads/2012/12/2012-12-19-1355925145_1024x600_scrot-96x96.png',
+            'http://some.blog/wp-content/uploads/2012/12/2012-12-19-1355925145_1024x600_scrot-96x96.png',
+            'http://some.blog/wp-content/uploads/2012/12/2012-12-19-1355925145_1024x600_scrot-48x48.png',
+            'http://some.blog/wp-content/uploads/2012/12/2012-12-19-1355925145_1024x600_scrot-96x96.png',
+            'http://some.blog/wp-content/uploads/2012/12/2012-12-19-1355925145_1024x600_scrot-150x150.png'
+        ]
+
+        for link in image_thumbnails:
+            self.assertTrue(
+                link in self.module.links,
+                'No link to "{0}" found in {map}.'.format(
+                    link,
+                    map=self.module.links
+                )
+            )
+
     def test_transforming_content(self):
         """Applying markup conversions to content."""
         transform_sourcecode = mock.MagicMock()
         transform_caption = mock.MagicMock()
         transform_newlines = mock.MagicMock()
 
-        with mock.patch('nikola.plugins.command_import_wordpress.CommandImportWordpress.transform_sourcecode', transform_sourcecode):
-            with mock.patch('nikola.plugins.command_import_wordpress.CommandImportWordpress.transform_caption', transform_caption):
-                with mock.patch('nikola.plugins.command_import_wordpress.CommandImportWordpress.transform_multiple_newlines', transform_newlines):
+        with mock.patch('nikola.plugins.command.import_wordpress.CommandImportWordpress.transform_sourcecode', transform_sourcecode):
+            with mock.patch('nikola.plugins.command.import_wordpress.CommandImportWordpress.transform_caption', transform_caption):
+                with mock.patch('nikola.plugins.command.import_wordpress.CommandImportWordpress.transform_multiple_newlines', transform_newlines):
                     self.import_command.transform_content("random content")
 
         self.assertTrue(transform_sourcecode.called)
